==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/PodStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class PodStatusBuilder extends PodStatusFluentImpl<PodStatusBuilder> implements VisitableBuilder<PodStatus,PodStatusBuilder>{

    PodStatusFluent<?> fluent;
    Boolean validationEnabled;

    public PodStatusBuilder(){
            this(true);
    }
    public PodStatusBuilder(Boolean validationEnabled){
            this(new PodStatus(), validationEnabled);
    }
    public PodStatusBuilder(PodStatusFluent<?> fluent){
            this(fluent, true);
    }
    public PodStatusBuilder(PodStatusFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new PodStatus(), validationEnabled);
    }
    public PodStatusBuilder(PodStatusFluent<?> fluent,PodStatus instance){
            this(fluent, instance, true);
    }
    public PodStatusBuilder(PodStatusFluent<?> fluent,PodStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withConditions(instance.getConditions()); 
            fluent.withContainerStatuses(instance.getContainerStatuses()); 
            fluent.withHostIP(instance.getHostIP()); 
            fluent.withMessage(instance.getMessage()); 
            fluent.withPhase(instance.getPhase()); 
            fluent.withPodIP(instance.getPodIP()); 
            fluent.withReason(instance.getReason()); 
            fluent.withStartTime(instance.getStartTime()); 
            this.validationEnabled = validationEnabled; 
    }
    public PodStatusBuilder(PodStatus instance){
            this(instance,true);
    }
    public PodStatusBuilder(PodStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withConditions(instance.getConditions()); 
            this.withContainerStatuses(instance.getContainerStatuses()); 
            this.withHostIP(instance.getHostIP()); 
            this.withMessage(instance.getMessage()); 
            this.withPhase(instance.getPhase()); 
            this.withPodIP(instance.getPodIP()); 
            this.withReason(instance.getReason()); 
            this.withStartTime(instance.getStartTime()); 
            this.validationEnabled = validationEnabled; 
    }

    public PodStatus build(){
            PodStatus buildable = new PodStatus(fluent.getConditions(),fluent.getContainerStatuses(),fluent.getHostIP(),fluent.getMessage(),fluent.getPhase(),fluent.getPodIP(),fluent.getReason(),fluent.getStartTime());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PodStatusBuilder that = (PodStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.1.0-sources.jar: io/fabric8/kubernetes/api/model/PodStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodStatusBuilder extends PodStatusFluentImpl<PodStatusBuilder> implements VisitableBuilder<PodStatus,PodStatusBuilder>{

    PodStatusFluent<?> fluent;
    Boolean validationEnabled;

    public PodStatusBuilder(){
            this(true);
    }
    public PodStatusBuilder(Boolean validationEnabled){
            this(new PodStatus(), validationEnabled);
    }
    public PodStatusBuilder(PodStatusFluent<?> fluent){
            this(fluent, true);
    }
    public PodStatusBuilder(PodStatusFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new PodStatus(), validationEnabled);
    }
    public PodStatusBuilder(PodStatusFluent<?> fluent,PodStatus instance){
            this(fluent, instance, true);
    }
    public PodStatusBuilder(PodStatusFluent<?> fluent,PodStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withConditions(instance.getConditions()); 
            fluent.withContainerStatuses(instance.getContainerStatuses()); 
            fluent.withHostIP(instance.getHostIP()); 
            fluent.withMessage(instance.getMessage()); 
            fluent.withPhase(instance.getPhase()); 
            fluent.withPodIP(instance.getPodIP()); 
            fluent.withReason(instance.getReason()); 
            fluent.withStartTime(instance.getStartTime()); 
            this.validationEnabled = validationEnabled; 
    }
    public PodStatusBuilder(PodStatus instance){
            this(instance,true);
    }
    public PodStatusBuilder(PodStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withConditions(instance.getConditions()); 
            this.withContainerStatuses(instance.getContainerStatuses()); 
            this.withHostIP(instance.getHostIP()); 
            this.withMessage(instance.getMessage()); 
            this.withPhase(instance.getPhase()); 
            this.withPodIP(instance.getPodIP()); 
            this.withReason(instance.getReason()); 
            this.withStartTime(instance.getStartTime()); 
            this.validationEnabled = validationEnabled; 
    }

    public PodStatus build(){
            PodStatus buildable = new PodStatus(fluent.getConditions(),fluent.getContainerStatuses(),fluent.getHostIP(),fluent.getMessage(),fluent.getPhase(),fluent.getPodIP(),fluent.getReason(),fluent.getStartTime());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            PodStatusBuilder that = (PodStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
